@@ -5,11 +5,11 @@ pInt = None
 # Check the correct constructors are available
 p = Pop(pInt)
 
-p = Pop(pInt, 0)
+p = Pop(pInt, False)
 
 # Check overloaded in const only and pointers/references which target
 # languages cannot disambiguate
-if p.hip(0) != 701:
+if p.hip(False) != 701:
     raise RuntimeError, "Test 1 failed"
 
 if p.hip(pInt) != 702:
@@ -19,14 +19,14 @@ if p.hip(pInt) != 702:
 if p.hop(pInt) != 805:
     raise RuntimeError, "Test 3 failed"
 
-if p.hop(0) != 801:
+if p.hop(False) != 801:
     raise RuntimeError, "Test 4 failed"
 
 # Few more variations and order shuffled
-if p.pop(0) != 901:
+if p.pop(False) != 901:
     raise RuntimeError, "Test 5 failed"
 
-if p.pop(pInt) != 902:
+if p.pop(pInt) != 904:
     raise RuntimeError, "Test 6 failed"
 
 if p.pop() != 905:
@@ -36,11 +36,11 @@ if p.pop() != 905:
 if p.bop(pInt) != 1001:
     raise RuntimeError, "Test 8 failed"
 
-if p.bip(pInt) != 2001:
+if p.bip(pInt) != 2002:
     raise RuntimeError, "Test 9 failed"
 
 # Globals
-if muzak(0) != 3001:
+if muzak(False) != 3001:
     raise RuntimeError, "Test 10 failed"
 
 if muzak(pInt) != 3002:
